powered by
The coordinates of the vertices of a 3D convex hull.
VerticesXYZ(hull)
A matrix with three columns. Each row represents the coordinates of a vertex and the row names are the ids of the vertices.
an output of cxhull applied to 3D points
cxhull